/************* Arduino Pedometer with HC-05 ******************
  This project collects data from the ADXL-335 accelerometer.
  Arduino processes it and calculates the "No. of Steps" taken
  from the time of power up. the data is encoded in Json string format
  and sent serially using a BT module HC-05.
  ---------------------------------------------------------------------
  original pedometer code + supporting systems: jatinbatra (http://www.instructables.com/member/jatinbatra/)
  linear move code from Garth's website 
  

  ----------------------- CURRENT connection details --------------------------
  ADXL335 accelerometer & Arduino nano:
  Vcc --> +3.3v
  X --> A5
  Y --> A4
  Z --> A3
  Gnd --> gnd
  BT HC05 Tx to software Rx (0)
  BT HC05 Rx to software Tx (1)
  you can change the pins in included .h file
  ----------------------------------------------------------------------
  Libraries to download for this code:
  ArduinoJson: https://github.com/bblanchon/ArduinoJson
  SoftwareSerial: https://github.com/arduino/Arduino/tree/master/hardware/arduino/avr/libraries/SoftwareSerial
**********************************************************/
 
#include "ArduinoPedometer.h"
#include <Servo.h>

ArduinoPedometer fp; //create an instacne called "fp" for the class "ArduinoPedometer"
int x;


int SERVO_PIN = 12;
Servo myServo;

unsigned long now;
unsigned long lastUpdateTime = 0;
unsigned long updateInterval = 10000;
int spi = 9;
int lastX = 0;

int stepGoal = 0;

void setup()
{
  Serial.begin(9600);
  fp.calibrate(); // perform calibration to get x,y,z parameters.
  delay(1000);

  
  myServo.attach(SERVO_PIN);
}

void linear_move(int start, int end, float speed)
{
  const int interval = 20;
  float step = speed * 0.001 * interval;
  float angle = start;

  
  do {
    myServo.write(angle);  // update the servo output
    delay(interval);     // pause for the sampling interval
   
    if (end >= start) {
      angle += step;       // movement in the positive direction
      if (angle > end) angle = end;
    } else {
      angle -= step;      // movement in the negative direction
      if (angle < end) angle = end;
    }
  } while (angle != end);

  // Update the servo with the exact endpoint before returning.
  myServo.write(end);
}


void loop()
{
  now = millis();
  x = fp.getPedo(); //get the no. of steps
  Serial.print(x); //print the value in json format in software serial.
  Serial.print('\n');

  linear_move(20,180,(spi*10));
  linear_move(180,20,(spi*10));

  if (now > lastUpdateTime + updateInterval){
    /*IF SERIAL WORKS: 
     * use output from p5 instead of spi
     * use spi as input for p5 (maybe u could have a nice graph)
     * if(Serial.available()>0){
     * stepGoal = Serial.readString();
     * }
     * 
     */
   
    spi = ((x-lastX)/10);
    lastX = x;
    Serial.print("spi =");
    Serial.print(spi);
    lastUpdateTime = now;
    /* for checking: linear_move(20,180,100);*/
  }
}

//NEXT UP: rewrite linear_move so there is no delay ++ rewrite ArduinoPedometer.cpp











